function [xt,xb,yo,B,R,d,G]=init_cafe()
///////////////////////////////////
//  init
//
// Initialisation des parametres de l'experience jumelles
// 
// ncont = 2 car  x = [alpha P]
// nobs : nombre d'observations, parametre ajustable
//
// xt : etat vrai, vecteur colonne (ncont x 1) 
// xb : ebauche, vecteur colonne (ncont x 1)
// yo : observations, vecteur colonne (nobs x 1)
// B : matrice des covariances d'erreur d'ebauche (ncont x ncont)
// R : matrice des covariances d'erreur d'observatin (nobs x nobs)
// d : innovation, vecteur colonne (nobs x 1)
// G : operateur d'observation linearise, matrice (nobs x ncont)
//
//
// calG_cafe.sci : operateur d'observation
// Glin_cafe.sci : matrice operateur d'observation linearise
// 
/////////////////////////////////////////////////////    

// Variables globales 
global timeobs  // temps des observations, vecteur (nobs x 1) 
global timevisu // temps des visualisations, vecteur (nvisu x 1)
global timecalG // temps ajustable pour l'operateur calG
global jalea // numero du tirage aleatoire 

///////////////////////////////////////////////////
// MODIFIER ICI LES PARAMETRES                  //
/////////////////////////////////////////////////
alphat=1; Pt=1;  // etat vrai (alpha, P)^t 
// Ref : alphat=1; Pt=1;
alphab=.8; Pb=.8;  // ebauche   (alpha, P)^b 
// Ref : alphab=.8; Pb=1.2;
nobs=3; // nombre d'observations 
// Ref : nobs=3;
tmaxobs=1.5;  // temps max des observations
// Ref :  tmaxobs=1.5;
sigBalpha=.3*alphab; // erreur d'ebauche sur alpha 
// Ref : sigBalpha=.3*alphab;
sigBP=.3*Pb; // erreur d'ebauche sur P 
// Ref : sigBP=.3*Pb; 
rho=.0; // correlation d'erreur d'ebauche 
// Ref : rho=.0; 
sigR=.1*Pt/alphat; // erreur de mesure 
// Ref : sigR=.1*Pt/alphat;
tmaxvisu=5; // temps maximum du modele 
// Ref : tmaxvisu=5;
nvisu=101; // nombre de points pour la visualisation 
// Ref : nvisu=101; 
/////////////////////////////////////////////////////

// Impression des parametres
if(jalea==1)
  disp(sprintf('Etat vrai : alphat=%3.2g, Pt=%3.2g',alphat,Pt))
  disp(sprintf('Ebauche : alphab=%3.2g, Pb=%3.2g',alphab,Pb))
  disp(sprintf('Nombre observations : nobs=%3i',nobs))
  disp(sprintf('Temps max observations : tmaxobs=%3.2g',tmaxobs))
  disp(sprintf('Erreurs ebauche : sigBalpha=%3.2g, sigBP=%3.2g, rho=%3.2g', ... 
               sigBalpha,sigBP,rho))
  disp(sprintf('Erreur de mesures : sigR=%3.2g',sigR))
end

// temps des visualisations 
dtvisu=tmaxvisu/nvisu; 
timevisu=(0:dtvisu:tmaxvisu)';

// temps des observations 
dtobs=tmaxobs/nobs;
timeobs=(dtobs:dtobs:tmaxobs)';

// etat vrai
xt=[alphat; Pt]; 

// ebauche
xb=[alphab; Pb];

// erreurs de mesures pour experience jumelle
E=rand(1,nobs); // erreurs gaussiennes d'ecart-type 1

// mesures artificielles a partir de l'etat vrai
timecalG=timeobs; // temps de observations pour calG et Glin
yo=calG_cafe(xt)+sigR*E';

// matrice B des covariances d'erreurs d'ebauche
B=[sigBalpha^2 rho*sigBalpha*sigBP; rho*sigBalpha*sigBP sigBP^2];

// natrice R des covariances d'erreurs d'observation 
R=sigR^2*eye(nobs,nobs);

// inovation
d=yo-calG_cafe(xb)

// matrice G de l'operateur d'observation linearise
G=Glin_cafe(xb)

endfunction
